==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/installer/messages/cs/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>Účet</strong> administrátora',
    '<strong>Configuration</strong>' => '<strong>Přednastavení</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>Výborně</strong>, jste hotovi.',
    '<strong>Database</strong> Configuration' => '<strong>Nastavení</strong> databáze',
    '<strong>Example</strong> contents' => '<strong>Ukázkové</strong> příspěvky',
    '<strong>Pretty URLs</strong> configuration' => '<strong>Konfigurace hezkých adres URL</strong>',
    '<strong>Scheduled jobs</strong>' => '<strong>Naplánované úlohy</strong>',
    '<strong>System</strong> Check' => '<strong>Kontrola</strong> systému',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Vítejte</strong> v síti HumHub',
    'Add following the lines to the crontab:' => 'Do crontab přidejte následující řádky:',
    'Allow access for non-registered users to public content (guest access)' => 'Povolit přístup nepřihlášeným uživatelům k veřejným příspěvkům',
    'Allow friendships between members' => 'Povolit přátelství mezi členy',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Níže prosím zadejte vaše údaje pro připojení k databázi. Jestliže si jimi nejste jisti, obraťte se na správce vašeho serveru.',
    'Calvin Klein – Between love and madness lies obsession.' => 'Mně se hodně líbilo to přirovnání, že je Bůh jako náš otec. Myslím, že kdo má děti, dokáže si dobře představit, co to znamená.',
    'Check again' => 'Zkontrolovat znovu',
    'Congratulations! Everything is ok and ready to start over!' => 'Výborně, vše funguje, jak má, a je nachystáno k instalaci!',
    'Create Admin Account' => 'Vytvořit účet administrátora',
    'Create the database if it doesn\'t exist yet.' => 'Pokud databáze ještě neexistuje, vytvořte ji.',
    'Downloading & Installing Modules...' => 'Stahuji a instaluji modul(y)...',
    'External users can register (show registration form on login)' => 'Povolit registraci novým uživatelům (bude se zobrazovat formulář registrace)',
    'Here you can decide how new, unregistered users can access HumHub.' => 'Zde se můžete rozhodnout, co všechno mohou dělat neregistrovaní uživatelé.',
    'Hostname' => 'Hostname',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Hostname vašeho MySQL serveru (např. localhost, běží-li MySQL na stejném serveru)',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub je možné rozšířit mnoha moduly podle toho, jaké funkce zrovna potřebujete. Následující moduly jsme pro vás vybrali na základě předchozí volby použití, další moduly si ale můžete kdykoliv sami přidat nebo odebrat v Administraci.',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => 'HumHub používá úlohy cron k provádění naplánovaných nebo potenciálně náročných úloh, jako je rozesílání e-mailových souhrnů a oznámení nebo optimalizace vyhledávacího indexu.',
    'I want to use HumHub for:' => 'Chci používat HumHub pro:',
    'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => 'Pro aktivaci této funkce je nutné upravit konfiguraci HumHubu a případně i konfiguraci WebServeru.',
    'Initializing database...' => 'Naplňuji databázi...',
    'Installation Example:' => 'Installation Example:',
    'My club' => 'Klub',
    'My community' => 'Skupina',
    'My company (Social Intranet / Project management)' => 'Společnost/firma',
    'My educational institution (school, university)' => 'Vzdělávací instituce (škola, univerzita)',
    'Name of Database' => 'Databáze',
    'Name of your network' => 'Název vaší sítě',
    'Newly registered users have to be activated by an admin first' => 'Noví uživatelé musí být nejdříve schválení administrátorem',
    'Next' => 'Další',
    'Nike – Just buy it. :wink:' => 'Asi nejvíc vývojová psychologie dítěte. Měl dobré postřehy.',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Nyní můžete vaší síti zvolit název. Výchozí název lze přepsat na jiný, např. název vaší firmy, organizaci či spolku.',
    'Ohh, something went wrong!' => 'Jejda, něco se porouchalo...',
    'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => 'Na straně HumHubu je třeba upravit konfigurační soubor <code>{configFile}</code> a přidat následující blok:',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => 'Otevřete crontab uživatele procesu HumHub/PHP, např. <code>{user}</code>.',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => 'Volitelně: Port vašeho databázového serveru MySQL. Pro použití výchozího portu nechte prázdné.',
    'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => 'V naší dokumentaci najdete podrobnější informace o <a href="{link}">pěkných adresách URL</a>.',
    'Password' => 'Heslo',
    'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => 'Ve výchozím nastavení obsahuje adresa URL HumHub v adrese soubor <code>index.php</code>, což vede k adrese URL, která vypadá jako „<a>https://example.com/index.php?r=dashboard% například 2Fdashboard</a>“. Pomocí funkce Pretty URL nebo URL Rewriting je možné vytvářet kratší a srozumitelnější adresy URL, například „<a>https://example.com/dashboard</a>“.',
    'Port' => 'Port',
    'Recommended <strong>Modules</strong>' => '<strong>Doporučené</strong> moduly',
    'Registered members can invite new users via email' => 'Registrovaní uživatelé mohou zvát další',
    'Registered members can invite new users via link' => 'Registrovaní členové mohou pozvat nové uživatele prostřednictvím odkazu',
    'Security <strong>Settings</strong>' => '<strong>Nastavení</strong> soukromí',
    'Set up example content (recommended)' => 'Vytvořit pár příspěvků na ukázku',
    'Sign in' => 'Přihlásit se',
    'Skip this step, I want to set up everything manually' => 'Přeskočit, nastavím si vše později',
    'Social Network <strong>Name</strong>' => '<strong>Název</strong> sítě',
    'The installation completed successfully! Have fun with your new social network.' => 'Instalace byla úspěšná! Přejeme, ať vám síť dobře slouží.',
    'The name of the database you want to run HumHub in.' => 'Jméno databáze, do které chcete HumHub nainstalovat.',
    'This overview shows all system requirements of HumHub.' => 'Tento přehled ukazuje všechny požadavky HumHubu.',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => 'Toto téma je podrobněji popsáno v naší <a href="{link}">dokumentaci</a>. Pokud máte potíže s nastavením plánování úloh popsaným v dokumentaci, obraťte se na správce serveru, který vám poskytne podporu.',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Tento průvodce vám pomůže nainstalovat a nastavit síť HumHub.<br><br>Chcete-li pokračovat, klikněte na tlačítko Další.',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Pokud chcete, můžeme vám po instalaci vytvořit pár ukázkových příspěvků, abyste viděli, jak to vypadá. Tyto příspěvky pak můžete kdykoliv smazat.',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Nachystali jsme pár základních přednastavení pro určitá použití. Pokud chcete, můžete si jedno zvolit, nebo vše nastavit později manuálně.',
    'Username' => 'Uživatelské jméno',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Kdo jste dneska byli na tom semináři v aule - co vás nejvíc zaujalo?',
    'Welcome Space' => 'Uvítací prostor',
    'Yay! I\'ve just installed HumHub :sunglasses:' => 'Jupí, právě jsme nainstalovali HumHub :sunglasses:',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Už jsme skoro na konci, ještě vytvoříme účet administátora. S tímto účtem můžete spravovat celou síť.',
    'Your MySQL password.' => 'Heslo pro přístup k databázi',
    'Your MySQL username' => 'Uživatelské jméno pro přístup k databázi',
    'Your first sample space to discover the platform.' => 'Toto je první prostor, ve kterém vítáme nové uživatele.',
    'Default Language' => '',
    'Default Timezone' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/installer/messages/cs/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>Účet</strong> administrátora',
    '<strong>Configuration</strong>' => '<strong>Přednastavení</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>Výborně</strong>, jste hotovi.',
    '<strong>Database</strong> Configuration' => '<strong>Nastavení</strong> databáze',
    '<strong>Example</strong> contents' => '<strong>Ukázkové</strong> příspěvky',
    '<strong>Scheduled jobs</strong>' => '<strong>Naplánované úlohy</strong>',
    '<strong>System</strong> Check' => '<strong>Kontrola</strong> systému',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>Vítejte</strong> v síti HumHub',
    'Add following the lines to the crontab:' => 'Do crontab přidejte následující řádky:',
    'Allow access for non-registered users to public content (guest access)' => 'Povolit přístup nepřihlášeným uživatelům k veřejným příspěvkům',
    'Allow friendships between members' => 'Povolit přátelství mezi členy',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => 'Níže prosím zadejte vaše údaje pro připojení k databázi. Jestliže si jimi nejste jisti, obraťte se na správce vašeho serveru.',
    'Calvin Klein – Between love and madness lies obsession.' => 'Mně se hodně líbilo to přirovnání, že je Bůh jako náš otec. Myslím, že kdo má děti, dokáže si dobře představit, co to znamená.',
    'Check again' => 'Zkontrolovat znovu',
    'Congratulations! Everything is ok and ready to start over!' => 'Výborně, vše funguje, jak má, a je nachystáno k instalaci!',
    'Create Admin Account' => 'Vytvořit účet administrátora',
    'Create the database if it doesn\'t exist yet.' => 'Pokud databáze ještě neexistuje, vytvořte ji.',
    'Downloading & Installing Modules...' => 'Stahuji a instaluji modul(y)...',
    'External users can register (show registration form on login)' => 'Povolit registraci novým uživatelům (bude se zobrazovat formulář registrace)',
    'Here you can decide how new, unregistered users can access HumHub.' => 'Zde se můžete rozhodnout, co všechno mohou dělat neregistrovaní uživatelé.',
    'Hostname' => 'Hostname',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'Hostname vašeho MySQL serveru (např. localhost, běží-li MySQL na stejném serveru)',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub je možné rozšířit mnoha moduly podle toho, jaké funkce zrovna potřebujete. Následující moduly jsme pro vás vybrali na základě předchozí volby použití, další moduly si ale můžete kdykoliv sami přidat nebo odebrat v Administraci.',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => 'HumHub používá úlohy cron k provádění naplánovaných nebo potenciálně náročných úloh, jako je rozesílání e-mailových souhrnů a oznámení nebo optimalizace vyhledávacího indexu.',
    'I want to use HumHub for:' => 'Chci používat HumHub pro:',
    'Initializing database...' => 'Naplňuji databázi...',
    'Installation Example:' => 'Installation Example:',
    'My club' => 'Klub',
    'My community' => 'Skupina',
    'My company (Social Intranet / Project management)' => 'Společnost/firma',
    'My educational institution (school, university)' => 'Vzdělávací instituce (škola, univerzita)',
    'Name of Database' => 'Databáze',
    'Name of your network' => 'Název vaší sítě',
    'Newly registered users have to be activated by an admin first' => 'Noví uživatelé musí být nejdříve schválení administrátorem',
    'Next' => 'Další',
    'Nike – Just buy it. :wink:' => 'Asi nejvíc vývojová psychologie dítěte. Měl dobré postřehy.',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => 'Nyní můžete vaší síti zvolit název. Výchozí název lze přepsat na jiný, např. název vaší firmy, organizaci či spolku.',
    'Ohh, something went wrong!' => 'Jejda, něco se porouchalo...',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => 'Otevřete crontab uživatele procesu HumHub/PHP, např. <code>{user}</code>.',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => 'Volitelně: Port vašeho databázového serveru MySQL. Pro použití výchozího portu nechte prázdné.',
    'Password' => 'Heslo',
    'Port' => 'Port',
    'Recommended <strong>Modules</strong>' => '<strong>Doporučené</strong> moduly',
    'Registered members can invite new users via email' => 'Registrovaní uživatelé mohou zvát další',
    'Registered members can invite new users via link' => 'Registrovaní členové mohou pozvat nové uživatele prostřednictvím odkazu',
    'Security <strong>Settings</strong>' => '<strong>Nastavení</strong> soukromí',
    'Set up example content (recommended)' => 'Vytvořit pár příspěvků na ukázku',
    'Sign in' => 'Přihlásit se',
    'Skip this step, I want to set up everything manually' => 'Přeskočit, nastavím si vše později',
    'Social Network <strong>Name</strong>' => '<strong>Název</strong> sítě',
    'The installation completed successfully! Have fun with your new social network.' => 'Instalace byla úspěšná! Přejeme, ať vám síť dobře slouží.',
    'The name of the database you want to run HumHub in.' => 'Jméno databáze, do které chcete HumHub nainstalovat.',
    'This overview shows all system requirements of HumHub.' => 'Tento přehled ukazuje všechny požadavky HumHubu.',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => 'Toto téma je podrobněji popsáno v naší <a href="{link}">dokumentaci</a>. Pokud máte potíže s nastavením plánování úloh popsaným v dokumentaci, obraťte se na správce serveru, který vám poskytne podporu.',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => 'Tento průvodce vám pomůže nainstalovat a nastavit síť HumHub.<br><br>Chcete-li pokračovat, klikněte na tlačítko Další.',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => 'Pokud chcete, můžeme vám po instalaci vytvořit pár ukázkových příspěvků, abyste viděli, jak to vypadá. Tyto příspěvky pak můžete kdykoliv smazat.',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => 'Nachystali jsme pár základních přednastavení pro určitá použití. Pokud chcete, můžete si jedno zvolit, nebo vše nastavit později manuálně.',
    'Username' => 'Uživatelské jméno',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => 'Kdo jste dneska byli na tom semináři v aule - co vás nejvíc zaujalo?',
    'Welcome Space' => 'Uvítací prostor',
    'Yay! I\'ve just installed HumHub :sunglasses:' => 'Jupí, právě jsme nainstalovali HumHub :sunglasses:',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => 'Už jsme skoro na konci, ještě vytvoříme účet administátora. S tímto účtem můžete spravovat celou síť.',
    'Your MySQL password.' => 'Heslo pro přístup k databázi',
    'Your MySQL username' => 'Uživatelské jméno pro přístup k databázi',
    'Your first sample space to discover the platform.' => 'Toto je první prostor, ve kterém vítáme nové uživatele.',
    '<strong>Apache</strong> web server detected.' => '',
    '<strong>Nginx</strong> web server detected.' => '',
    '<strong>Pretty URLs</strong>' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'Ensure the following rule is present in your configuration: <strong>try_files $uri $uri/ /index.php?$args;</strong>.' => '',
    'For more information on this topic, please refer to our <a href="{link}" target="_blank">documentation</a>.' => '',
    'In the installation folder, locate the <strong>.env.example</strong> file and copy its contents into the <strong>.env</strong> file. Next, find the <strong>Pretty URLs</strong> block and uncomment it by removing the <strong>#</strong> symbol.' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'Make sure that the following file is writable: thi' => '',
    'Pretty URLs may not work correctly.' => '',
    'Pretty URLs should work correctly.' => '',
    'The <strong>.htaccess</strong> file is in place.' => '',
    'The <strong>.htaccess</strong> file is not in place. In the installation folder, locate the <strong>.htaccess.dist</strong> file and rename it to <strong>.htaccess</strong>.' => '',
    'The <strong>mod_rewrite</strong> module is active.' => '',
    'The <strong>mod_rewrite</strong> module is not enabled.' => '',
    'Unable to automatically detect your web server type. Please ensure URL rewriting is configured.' => '',
];
